@@ -800,7 +800,8 @@ void isoburn_disc_write(struct burn_write_opts *opts, struct burn_disc *disc)
        ret= lstat(adr, &stbuf);
        if(ret!=-1)
          if(S_ISREG(stbuf.st_mode))
-           truncate(adr, nwa * (off_t) 2048);
+           ret= truncate(adr, nwa * (off_t) 2048);
+           /* (result of truncate intentionally ignored) */
      }
    }
  }
