@@ -220,7 +220,7 @@ void isoburn_version(int *major, int *minor, int *micro);
 */
 #define isoburn_libisofs_req_major  0
 #define isoburn_libisofs_req_minor  6
-#define isoburn_libisofs_req_micro 32 
+#define isoburn_libisofs_req_micro 34 
 
 /** The minimum version of libburn to be used with this version of libisoburn
     at compile time.
@@ -228,7 +228,7 @@ void isoburn_version(int *major, int *minor, int *micro);
 */
 #define isoburn_libburn_req_major  0
 #define isoburn_libburn_req_minor  8
-#define isoburn_libburn_req_micro  2
+#define isoburn_libburn_req_micro  4
 
 
 /** The minimum version of libisofs to be used with this version of libisoburn
@@ -263,8 +263,8 @@ int isoburn_libburn_req(int *major, int *minor, int *micro);
     @since 0.1.0
 */
 #define isoburn_header_version_major  0
-#define isoburn_header_version_minor  5
-#define isoburn_header_version_micro  8
+#define isoburn_header_version_minor  6
+#define isoburn_header_version_micro  0
 /** Note:
     Above version numbers are also recorded in configure.ac because libtool
     wants them as parameters at build time.
@@ -628,7 +628,7 @@ void isoburn_toc_disc_free(struct isoburn_toc_disc *disc);
     @since 0.1.6
     @param d     The drive with the media to inspect
     @param lba   The block number from where to read
-    @param image_blocks  The number of 2048 bytes blocks
+    @param image_blocks  Returns the number of 2048 bytes blocks in the session
     @param info  Caller provided memory, enough to take eventual info reply
     @param flag bit0-7: info return mode
                  0= do not return anything in info (do not even touch it)
