@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2007 Vreixo Formoso
  * Copyright (c) 2007 Mario Danic
- * Copyright (c) 2009 Thomas Schmitt
+ * Copyright (c) 2009 - 2010 Thomas Schmitt
  *
  * This file is part of the libisofs project; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License version 2 
@@ -9,6 +9,10 @@
  * See COPYING file for details.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "../config.h"
+#endif
+
 /*
    Use the copy of the struct burn_source definition in libisofs.h
 */
@@ -27,10 +31,7 @@
 #include "rockridge.h"
 #include "util.h"
 #include "system_area.h"
-
-#ifdef Libisofs_with_checksumS
 #include "md5.h"
-#endif
 
 #include <ctype.h>
 #include <stdlib.h>
@@ -72,19 +73,16 @@ void ecma119_image_free(Ecma119Image *t)
         free(t->input_charset);
     if (t->output_charset != NULL)
         free(t->output_charset);
-
+    if (t->bootsrc != NULL)
+        free(t->bootsrc);
     if (t->system_area_data != NULL)
         free(t->system_area_data);
-
-#ifdef Libisofs_with_checksumS
     if (t->checksum_ctx != NULL) { /* dispose checksum context */
         char md5[16];
         iso_md5_end(&(t->checksum_ctx), md5);
     }
     if (t->checksum_buffer != NULL)
         free(t->checksum_buffer);
-#endif
-
     if (t->writers != NULL)
         free(t->writers);
     free(t);
@@ -255,17 +253,11 @@ int ecma119_writer_compute_data_blocks(IsoImageWriter *writer)
     target->m_path_table_pos = target->curblock;
     target->curblock += DIV_UP(path_table_size, BLOCK_SIZE);
     target->path_table_size = path_table_size;
-
-#ifdef Libisofs_with_checksumS
-
     if (target->md5_session_checksum) {
         /* Account for tree checksum tag */
         target->checksum_tree_tag_pos = target->curblock;
         target->curblock++;
     }
-
-#endif /* Libisofs_with_checksumS */
-
     return ISO_SUCCESS;
 }
 
@@ -342,7 +334,7 @@ void write_one_dir_record(Ecma119Image *t, Ecma119Node *node, int file_id,
         iso_datetime_7(rec->recording_time, t->now, t->always_gmt);
     }
     rec->flags[0] = ((node->type == ECMA119_DIR) ? 2 : 0) | (multi_extend ? 0x80 : 0);
-    iso_bb(rec->vol_seq_number, 1, 2);
+    iso_bb(rec->vol_seq_number, (uint32_t) 1, 2);
     rec->len_fi[0] = len_fi;
 
     /*
@@ -420,9 +412,9 @@ int ecma119_writer_write_vol_desc(IsoImageWriter *writer)
     strncpy_pad((char*)vol.system_id, system_id, 32);
     strncpy_pad((char*)vol.volume_id, vol_id, 32);
     iso_bb(vol.vol_space_size, t->vol_space_size, 4);
-    iso_bb(vol.vol_set_size, 1, 2);
-    iso_bb(vol.vol_seq_number, 1, 2);
-    iso_bb(vol.block_size, BLOCK_SIZE, 2);
+    iso_bb(vol.vol_set_size, (uint32_t) 1, 2);
+    iso_bb(vol.vol_seq_number, (uint32_t) 1, 2);
+    iso_bb(vol.block_size, (uint32_t) BLOCK_SIZE, 2);
     iso_bb(vol.path_table_size, t->path_table_size, 4);
     iso_lsb(vol.l_path_table_pos, t->l_path_table_pos, 4);
     iso_msb(vol.m_path_table_pos, t->m_path_table_pos, 4);
@@ -736,16 +728,10 @@ int ecma119_writer_write_data(IsoImageWriter *writer)
     ret = write_path_tables(t);
     if (ret < 0)
         return ret;
-
-#ifdef Libisofs_with_checksumS
-
     if (t->md5_session_checksum) {
         /* Write tree checksum tag */
         ret = iso_md5_write_tag(t, 3);
     }
-
-#endif /* Libisofs_with_checksumS */
-
     return ret;
 }
 
@@ -933,8 +919,6 @@ void *write_function(void *arg)
         }
     }
 
-#ifdef Libisofs_with_checksumS
-
     /* Write superblock checksum tag */
     if (target->md5_session_checksum && target->checksum_ctx != NULL) {
         res = iso_md5_write_tag(target, 2);
@@ -942,9 +926,6 @@ void *write_function(void *arg)
             goto write_error;
     }
 
-#endif /* Libisofs_with_checksumS */
-
-
     /* write data for each writer */
     for (i = 0; i < target->nwriters; ++i) {
         writer = target->writers[i];
@@ -954,13 +935,9 @@ void *write_function(void *arg)
         }
     }
 
-#ifdef Libisofs_with_checksumS
-
     /* Transplant checksum buffer from Ecma119Image to IsoImage */
     transplant_checksum_buffer(target, 0);
 
-#endif
-
     iso_ring_buffer_writer_close(target->buffer, 0);
 
 #ifdef Libisofs_with_pthread_exiT
@@ -980,15 +957,11 @@ void *write_function(void *arg)
     }
     iso_ring_buffer_writer_close(target->buffer, 1);
 
-#ifdef Libisofs_with_checksumS
-
     /* Transplant checksum buffer away from Ecma119Image */
     transplant_checksum_buffer(target, 0);
     /* Invalidate the transplanted checksum buffer in IsoImage */
     iso_image_free_checksums(target->image, 0);
 
-#endif
-
 #ifdef Libisofs_with_pthread_exiT
     pthread_exit(NULL);
 #else
@@ -998,9 +971,6 @@ void *write_function(void *arg)
 }
 
 
-#ifdef Libisofs_with_checksumS
-
-
 static
 int checksum_prepare_image(IsoImage *src, int flag)
 {
@@ -1095,9 +1065,6 @@ int checksum_prepare_nodes(Ecma119Image *target, IsoNode *node, int flag)
 }
 
 
-#endif /* Libisofs_with_checksumS */
-
-
 static
 int ecma119_image_new(IsoImage *src, IsoWriteOpts *opts, Ecma119Image **img)
 {
@@ -1166,6 +1133,20 @@ int ecma119_image_new(IsoImage *src, IsoWriteOpts *opts, Ecma119Image **img)
     /* el-torito? */
     target->eltorito = (src->bootcat == NULL ? 0 : 1);
     target->catalog = src->bootcat;
+    if (target->catalog != NULL) {
+        target->num_bootsrc = target->catalog->num_bootimages;
+        target->bootsrc = calloc(target->num_bootsrc + 1,
+                                    sizeof(IsoFileSrc *));
+        if (target->bootsrc == NULL) {
+            ret = ISO_OUT_OF_MEM;
+            goto target_cleanup;
+        }
+        for (i= 0; i < target->num_bootsrc; i++)
+            target->bootsrc[i] = NULL;
+    } else {
+        target->num_bootsrc = 0;
+        target->bootsrc = NULL;
+    }
 
     if (opts->system_area_data != NULL) {
         system_area = opts->system_area_data;
@@ -1207,8 +1188,6 @@ int ecma119_image_new(IsoImage *src, IsoWriteOpts *opts, Ecma119Image **img)
         goto target_cleanup;
     }
 
-#ifdef Libisofs_with_checksumS
-
     target->md5_file_checksums = opts->md5_file_checksums;
     target->md5_session_checksum = opts->md5_session_checksum;
     strcpy(target->scdbackup_tag_parm, opts->scdbackup_tag_parm);
@@ -1226,8 +1205,6 @@ int ecma119_image_new(IsoImage *src, IsoWriteOpts *opts, Ecma119Image **img)
     target->checksum_range_size = 0;
     target->opts_overwrite = 0;
 
-#endif
-
     /*
      * 2. Based on those options, create needed writers: iso, joliet...
      * Each writer inits its structures and stores needed info into
@@ -1251,9 +1228,6 @@ int ecma119_image_new(IsoImage *src, IsoWriteOpts *opts, Ecma119Image **img)
         nwriters++;
     }
 
-
-#ifdef Libisofs_with_checksumS
-
     if ((target->md5_file_checksums & 1) || target->md5_session_checksum) {
         nwriters++;
         image_checksums_mad = 1; /* from here on the loaded checksums are
@@ -1270,9 +1244,6 @@ int ecma119_image_new(IsoImage *src, IsoWriteOpts *opts, Ecma119Image **img)
         target->checksum_idx_counter = 0;
     }
 
-#endif /* Libisofs_with_checksumS */
-
-
     target->writers = malloc(nwriters * sizeof(void*));
     if (target->writers == NULL) {
         ret = ISO_OUT_OF_MEM;
@@ -1330,19 +1301,12 @@ int ecma119_image_new(IsoImage *src, IsoWriteOpts *opts, Ecma119Image **img)
         goto target_cleanup;
     }
     file_src_writer_index = target->nwriters - 1;
-
-
-#ifdef Libisofs_with_checksumS
-
     if ((target->md5_file_checksums & 1) || target->md5_session_checksum) {
         ret = checksum_writer_create(target);
         if (ret < 0)
             goto target_cleanup;
     }
 
-#endif /* Libisofs_with_checksumS */
-
-
     /*
      * 3.
      * Call compute_data_blocks() in each Writer.
@@ -1441,8 +1405,6 @@ int ecma119_image_new(IsoImage *src, IsoWriteOpts *opts, Ecma119Image **img)
         memcpy(vol->std_identifier, "CD001", 5);
         vol->vol_desc_version[0] = 1;
 
-#ifdef Libisofs_with_checksumS
-
         /* Write relocated superblock checksum tag */
         tag_pos = voldesc_size / BLOCK_SIZE + 16 + 1;
         if (target->md5_session_checksum) {
@@ -1474,9 +1436,6 @@ int ecma119_image_new(IsoImage *src, IsoWriteOpts *opts, Ecma119Image **img)
             if (ret > 0)
                 opts->overwrite[i * 2048] = 0;
         }
-
-#endif /* Libisofs_with_checksumS */
-
     }
 
     /*
@@ -1488,8 +1447,6 @@ int ecma119_image_new(IsoImage *src, IsoWriteOpts *opts, Ecma119Image **img)
 
 
     /* 4. Create and start writing thread */
-
-#ifdef Libisofs_with_checksumS
     if (target->md5_session_checksum) {
         /* After any fake writes are done: Initialize image checksum context */
         if (target->checksum_ctx != NULL)
@@ -1503,8 +1460,6 @@ int ecma119_image_new(IsoImage *src, IsoWriteOpts *opts, Ecma119Image **img)
     iso_image_free_checksums(target->image, 0);
     image_checksums_mad = 0;
 
-#endif /* Libisofs_with_checksumS */
-
     /* ensure the thread is created joinable */
     pthread_attr_init(&(target->th_attr));
     pthread_attr_setdetachstate(&(target->th_attr), PTHREAD_CREATE_JOINABLE);
@@ -1529,14 +1484,8 @@ int ecma119_image_new(IsoImage *src, IsoWriteOpts *opts, Ecma119Image **img)
     return ISO_SUCCESS;
 
     target_cleanup: ;
-
-#ifdef Libisofs_with_checksumS
-
     if(image_checksums_mad) /* No checksums is better than mad checksums */
       iso_image_free_checksums(target->image, 0);
-
-#endif /* Libisofs_with_checksumS */
-
     ecma119_image_free(target);
     return ret;
 }
@@ -1676,17 +1625,11 @@ int iso_write(Ecma119Image *target, void *buf, size_t count)
         /* reader cancelled */
         return ISO_CANCELED;
     }
-
-#ifdef Libisofs_with_checksumS
-
     if (target->checksum_ctx != NULL) {
         /* Add to image checksum */
         target->checksum_counter += count;
         iso_md5_compute(target->checksum_ctx, (char *) buf, (int) count);
     }
-
-#endif /* Libisofs_with_checksumS */
-
     /* total size is 0 when writing the overwrite buffer */
     if (ret > 0 && (target->total_size != (off_t) 0)){
         unsigned int kbw, kbt;
@@ -1962,14 +1905,8 @@ int iso_write_opts_set_sort_files(IsoWriteOpts *opts, int sort)
 
 int iso_write_opts_set_record_md5(IsoWriteOpts *opts, int session, int files)
 {
-
-#ifdef Libisofs_with_checksumS
-
     opts->md5_session_checksum = session & 1;
     opts->md5_file_checksums = files & 3;
-
-#endif /* Libisofs_with_checksumS */
-
     return ISO_SUCCESS;
 }
 
@@ -1977,9 +1914,6 @@ int iso_write_opts_set_scdbackup_tag(IsoWriteOpts *opts,
                                      char *name, char *timestamp,
                                      char *tag_written)
 {
-
-#ifdef Libisofs_with_checksumS
-
     char eff_name[81], eff_time[19];
     int i;
 
@@ -2005,9 +1939,6 @@ int iso_write_opts_set_scdbackup_tag(IsoWriteOpts *opts,
     opts->scdbackup_tag_written = tag_written;
     if (tag_written != NULL)
         tag_written[0] = 0;
-
-#endif /* Libisofs_with_checksumS */
-
     return ISO_SUCCESS;
 }
 
