@@ -653,6 +653,8 @@ int iso_image_add_boot_image(IsoImage *image, const char *image_path,
     struct el_torito_boot_catalog *catalog = image->bootcat;
     ElToritoBootImage *boot_img;
 
+    if(catalog == NULL)
+      return ISO_BOOT_NO_CATALOG;
     if (catalog->num_bootimages >= Libisofs_max_boot_imageS)
         return ISO_BOOT_IMAGE_OVERFLOW;
     ret = create_image(image, image_path, type, &boot_img);
@@ -674,6 +676,18 @@ int iso_image_set_boot_catalog_weight(IsoImage *image, int sort_weight)
     return 1;
 }
 
+/* API */
+int iso_image_set_boot_catalog_hidden(IsoImage *image, int hide_attrs)
+{
+    if (image->bootcat == NULL)
+        return 0;
+    if (image->bootcat->node == NULL)
+        return 0;
+    iso_node_set_hidden((IsoNode *) image->bootcat->node, hide_attrs);
+    return 1;
+}
+
+
 void el_torito_boot_catalog_free(struct el_torito_boot_catalog *cat)
 {
     struct el_torito_boot_image *image;
