@@ -95,6 +95,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  for(i=0;i<m->rc_filename_count-1;i++)
    strcpy(m->rc_filenames[i],Xorriso_sys_rc_nameS[i]);
  m->rc_filenames[m->rc_filename_count-1][0]= 0;
+ m->mkisofsrc_done= 0;
 
  m->wdi[0]= 0;
  strcpy(m->wdx, m->initial_wdx);
@@ -128,6 +129,9 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->application_id[0]= 0;
  m->system_id[0]= 0;
  m->volset_id[0]= 0;
+ m->copyright_file[0]= 0;
+ m->biblio_file[0]= 0;
+ m->abstract_file[0]= 0;
  m->session_logfile[0]= 0;
  m->session_lba= -1;
  m->session_blocks= 0;
@@ -181,6 +185,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->stdio_sync= 0;
  m->keep_boot_image= 0;
  m->boot_image_cat_path[0]= 0;
+ m->boot_image_cat_hidden= 0;
  m->boot_count= 0;
  m->boot_platform_id= 0x00; /* El Torito Boot Catalog Platform ID: 0 = 80x86 */
  m->patch_isolinux_image= 0;
@@ -222,6 +227,8 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->temp_mem_limit= 16*1024*1024;
  m->file_size_limit= Xorriso_default_file_size_limiT;
  m->disk_exclusions= NULL;
+ m->iso_rr_hidings= NULL;
+ m->joliet_hidings= NULL;
  m->disk_excl_mode= 1;
  m->use_stdin= 0;
  m->result_page_length= 0;
@@ -333,6 +340,12 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
    m->pacifier_style= 2;
  }
  ret= Exclusions_new(&(m->disk_exclusions), 0);
+ if(ret<=0)
+   goto failure;
+ ret= Exclusions_new(&(m->iso_rr_hidings), 0);
+ if(ret<=0)
+   goto failure;
+ ret= Exclusions_new(&(m->joliet_hidings), 0);
  if(ret<=0)
    goto failure;
  Xorriso_relax_compliance(m, "default", 0);
@@ -389,6 +402,8 @@ int Xorriso_destroy(struct XorrisO **xorriso, int flag)
    free(m->out_charset);
  Xorriso_destroy_re(m,0);
  Exclusions_destroy(&(m->disk_exclusions), 0);
+ Exclusions_destroy(&(m->iso_rr_hidings), 0);
+ Exclusions_destroy(&(m->joliet_hidings), 0);
  Xorriso_destroy_all_extf(m, 0);
  Xorriso_lst_destroy_all(&(m->drive_blacklist), 0);
  Xorriso_lst_destroy_all(&(m->drive_greylist), 0);
