@@ -329,6 +329,7 @@ int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, int flag)
  Sectorbitmap_destroy(&(xorriso->in_sector_map), 0);
  Xorriso_destroy_hln_array(xorriso, 0);
  Xorriso_destroy_di_array(xorriso, 0);
+ xorriso->boot_count= 0;
 
  /* check for invalid state */
  if(state != BURN_DISC_BLANK && state != BURN_DISC_APPENDABLE &&
@@ -435,22 +436,14 @@ int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, int flag)
  xorriso->system_id[32]= 0;
  strncpy(xorriso->volset_id, un0(iso_image_get_volset_id(volset)), 128);
  xorriso->volset_id[128]= 0;
-
- /* <<< can be removed as soon as libisofs-0.6.24 is mandatory
- */
- if(strcmp(un0(iso_image_get_copyright_file_id(volset)), "_") == 0 &&
-    strcmp(un0(iso_image_get_abstract_file_id(volset)), "_") == 0 &&
-    strcmp(un0(iso_image_get_biblio_file_id(volset)), "_") == 0) {
-   /* This is bug output from libisofs <= 0.6.23 . The texts mean file names
-      and should have been empty to indicate that there are no such files.
-      It is obvious that not all three roles can be fulfilled by one file "_"
-      so that one cannot spoil anything by assuming them empty now.
-      Modern versions of libisofs are supposed to do this themselves.
-    */
-   iso_image_set_copyright_file_id(volset, "");
-   iso_image_set_abstract_file_id(volset, "");
-   iso_image_set_biblio_file_id(volset, "");
- }
+ strncpy(xorriso->copyright_file,
+         un0(iso_image_get_copyright_file_id(volset)), 37);
+ xorriso->copyright_file[37]= 0;
+ strncpy(xorriso->biblio_file, un0(iso_image_get_biblio_file_id(volset)), 37);
+ xorriso->biblio_file[37]= 0;
+ strncpy(xorriso->abstract_file,
+         un0(iso_image_get_abstract_file_id(volset)), 37);
+ xorriso->abstract_file[37]= 0;
 
  if(xorriso->out_drive_handle != NULL &&
     xorriso->out_drive_handle != xorriso->in_drive_handle) {
