@@ -509,7 +509,7 @@ int Xorriso_genisofs_ignore(struct XorrisO *xorriso, char *whom,
    ""
  };
  static char ignored_arg1_options[][41]= {
-   "-biblio", "-check-session", "-p", "-root",
+   "-check-session", "-hide-hfs", "-hide-hfs-list", "-p", "-preparer", "-root",
    "-old-root", "-table-name", "-volset-seqno", "-volset-size",
    ""
  };
@@ -566,6 +566,10 @@ int Xorriso_genisofs_help(struct XorrisO *xorriso, int flag)
 "  -f, -follow-links           Follow symbolic links",
 "  -graft-points               Allow to use graft points for filenames",
 "  -help                       Print option help",
+"  -hide GLOBFILE              Hide ISO9660/RR file",
+"  -hide-list FILE             File with list of ISO9660/RR files to hide",
+"  -hide-joliet GLOBFILE       Hide Joliet file",
+"  -hide-joliet-list FILE      File with list of Joliet files to hide",
 "  -input-charset CHARSET      Local input charset for file name conversion",
 "  -output-charset CHARSET     Output charset for file name conversion",
 "  -iso-level LEVEL            Set ISO9660 conformance level (1..3)",
@@ -578,12 +582,15 @@ int Xorriso_genisofs_help(struct XorrisO *xorriso, int flag)
 "  -o FILE, -output FILE       Set output file name",
 "  -m GLOBFILE, -exclude GLOBFILE",
 "                              Exclude file name",
+"  -x FILE, -old-exclude FILE  Exclude file name",
 "  -exclude-list FILE          File with list of file names to exclude",
 "  -pad                        Pad output by 300k (default)",
 "  -no-pad                     Do not pad output",
 "  -M FILE, -prev-session FILE Set path to previous session to merge",
 "  -C PARAMS, -cdrecord-params PARAMS",
 "                              Magic paramters from cdrecord",
+"  -dir-mode mode              Make the mode of all directories this mode.",
+"  -file-mode mode             Make the mode of all plain files this mode.",
 "  -path-list FILE             File with list of pathnames to process",
 "  --quoted_path_list FILE     File with list of quoted pathnames to process",
 "  -print-size                 Print estimated filesystem size and exit",
@@ -601,12 +608,16 @@ int Xorriso_genisofs_help(struct XorrisO *xorriso, int flag)
 "  -publisher PUB              Set Volume publisher",
 "  -A ID, -appid ID            Set Application ID",
 "  -sysid ID                   Set System ID",
+"  -abstract FILE              Set Abstract filename",
+"  -biblio FILE                Set Bibliographic filename",
+"  -copyright FILE             Set Copyright filename",
 "  -b FILE, -eltorito-boot FILE",
 "                              Set El Torito boot image name",
 "  -eltorito-alt-boot          Start specifying alternative El Torito boot parameters",
 "  --efi-boot FILE             Set El Torito EFI boot image name and type",
 "  -c FILE, -eltorito-catalog FILE",
 "                              Set El Torito boot catalog name",
+"  --boot-catalog-hide         Hide boot catalog from ISO9660/RR and Joliet",
 "  -boot-load-size #           Set numbers of load sectors",
 "  -no-emul-boot               Boot image is 'no emulation' image",
 "  -boot-info-table            Patch boot image with info table",
@@ -642,6 +653,86 @@ int Xorriso_genisofs_help(struct XorrisO *xorriso, int flag)
 }
 
 
+/* Perform hiding.
+   Cumbersome: The paths and patterns apply to the disk address and not
+   to the Rock Ridge address. Actually even the literal form of the
+   mkisofs pathspec would matter (e.g. "./" versus "").
+   But xorriso normalizes disk_paths before further processing. Thus
+   the literal form does not matter.
+*/
+int Xorriso_genisofs_hide(struct XorrisO *xorriso, char *whom,
+                          char *pattern, int hide_attrs, int flag)
+{
+ int zero= 0, ret;
+ char *argv[1];
+
+ if((hide_attrs & 3) == 0)
+   return(2);
+ if(strchr(pattern, '/') != NULL) {
+   argv[0]= pattern;
+   ret= Xorriso_option_not_paths(xorriso, 1, argv, &zero,
+                                 4 | (hide_attrs & 3));
+ } else {
+   ret= Xorriso_option_not_leaf(xorriso, pattern, hide_attrs & 3);
+ }
+ return(ret);
+}
+
+
+/* @param flag bit0= quoted list */
+int Xorriso_genisofs_hide_list(struct XorrisO *xorriso, char *whom,
+                               char *adr, int hide_attrs, int flag)
+{
+ int ret, linecount= 0, argc= 0, was_failure= 0, i, fret;
+ char **argv= NULL;
+ FILE *fp= NULL;
+
+ if(adr[0]==0) {
+   sprintf(xorriso->info_text,
+          "Empty file name given with -as %s -hide-%slist",
+           whom, hide_attrs == 1 ? "" : "joliet-");
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "WARNING", 0);
+   return(0);
+ }
+ ret= Xorriso_afile_fopen(xorriso, adr, "rb", &fp, 0);
+ if(ret <= 0)
+   return(0);
+ if(ret <= 0)
+   return(0);
+ while(1) {
+   ret= Xorriso_read_lines(xorriso, fp, &linecount, &argc, &argv,
+                           4 | (flag & 1) );
+   if(ret <= 0)
+     goto ex;
+   if(ret == 2)
+ break;
+   for(i= 0; i < argc; i++) {
+     if(argv[i][0] == 0)
+   continue;
+     ret= Xorriso_genisofs_hide(xorriso, whom, argv[i], hide_attrs, 0);
+     if(ret <= 0 || xorriso->request_to_abort) {
+       was_failure= 1;
+       fret= Xorriso_eval_problem_status(xorriso, ret, 1|2);
+       if(fret>=0)
+   continue;
+       if(ret > 0)
+         ret= 0;
+       goto ex;
+     }
+   }
+ }
+ ret= 1;
+ex:;
+ if(flag & 1)
+   Xorriso_read_lines(xorriso, fp, &linecount, &argc, &argv, 2);
+ if(fp != NULL && fp != stdin)
+   fclose(fp);
+ if(ret<=0)
+   return(ret);
+ return(!was_failure);
+}
+
+
 /* micro emulation of mkisofs */
 int Xorriso_genisofs(struct XorrisO *xorriso, char *whom,
                      int argc, char **argv, int flag)
@@ -649,12 +740,14 @@ int Xorriso_genisofs(struct XorrisO *xorriso, char *whom,
  int ret, i, j, was_path= 0, was_other_option= 0, mem_graft_points, mem;
  int do_print_size= 0, fd, idx, iso_level= 0, no_emul_boot= 0;
  int option_b= 0, was_failure= 0, fret, lower_r= 0, zero= 0;
+ int dir_mode= -1, file_mode= -1;
+ mode_t mode_and, mode_or;
+ int with_boot_image= 0, with_cat_path= 0;
  int *weight_list= NULL, weight_count= 0;
- int *boot_opt_list= NULL, boot_opt_count= 0;
+ int *delay_opt_list= NULL, delay_opt_count= 0;
  char sfe[5*SfileadrL], adr[SfileadrL+8], ra_text[80], pathspec[2*SfileadrL];
  char *ept, *add_pt, eff_path[SfileadrL], indev[SfileadrL+8], msc[80], *cpt;
  char *boot_path;
- static char *lower_r_args[3]= {"/", "-exec", "mkisofs_r"};
  static char *sort_weight_args[4]= {"", "-exec", "sort_weight", ""};
 
  strcpy(ra_text, xorriso->report_about_text);
@@ -664,13 +757,15 @@ int Xorriso_genisofs(struct XorrisO *xorriso, char *whom,
    Xorriso_no_malloc_memory(xorriso, NULL, 0);
    return(-1);
  }
- boot_opt_list= TSOB_FELD(int, argc + 1);
- if(boot_opt_list == NULL) {
+ delay_opt_list= TSOB_FELD(int, argc + 1);
+ if(delay_opt_list == NULL) {
    cpt= (char *) weight_list;
    Xorriso_no_malloc_memory(xorriso, &cpt, 0);
    return(-1);
  } 
 
+ if(xorriso->boot_image_cat_path[0])
+   with_cat_path= -1;
  adr[0]= indev[0]= msc[0]= 0;
  for(i= 0; i<argc; i++) {
    ret= Xorriso_genisofs_ignore(xorriso, whom, argv, &i, 1);
@@ -683,7 +778,8 @@ int Xorriso_genisofs(struct XorrisO *xorriso, char *whom,
      fd= xorriso->dev_fd_1;
      if(fd<0)
        fd= 1;
-     write(fd, xorriso->result_line, strlen(xorriso->result_line));
+     ret= write(fd, xorriso->result_line, strlen(xorriso->result_line));
+     /* (result of write intentionally ignored) */
      fsync(fd);
      Xorriso_option_version(xorriso, 0);
 
@@ -762,6 +858,25 @@ int Xorriso_genisofs(struct XorrisO *xorriso, char *whom,
        ret= Xorriso_option_charset(xorriso, argv[i], 3);
      if(ret <= 0)
        goto problem_handler_1;
+
+   } else if(strcmp(argv[i], "-hide") == 0 ||
+             strcmp(argv[i], "-hide-list") == 0 ||
+             strcmp(argv[i], "-hide-joliet") == 0 ||
+             strcmp(argv[i], "-hide-joliet-list") == 0) {
+     if(i+1>=argc)
+       goto not_enough_args;
+     i++;
+     if(strcmp(argv[i - 1], "-hide") == 0)
+       ret= Xorriso_genisofs_hide(xorriso, whom, argv[i], 1, 0);
+     else if(strcmp(argv[i - 1], "-hide-list") == 0)
+       ret= Xorriso_genisofs_hide_list(xorriso, whom, argv[i], 1, 0);
+     else if(strcmp(argv[i - 1], "-hide-joliet") == 0) 
+       ret= Xorriso_genisofs_hide(xorriso, whom, argv[i], 2, 0);
+     else if(strcmp(argv[i - 1], "-hide-joliet-list") == 0) 
+       ret= Xorriso_genisofs_hide_list(xorriso, whom, argv[i], 2, 0);
+     if(ret <= 0)
+       goto problem_handler_1;
+
    } else if(strcmp(argv[i], "--hardlinks")==0) {
      Xorriso_option_hardlinks(xorriso, "on", 0);
    } else if(strcmp(argv[i], "--acl")==0) {
@@ -921,39 +1036,35 @@ not_enough_args:;
      /* was already handled in first argument scan */;
    } else if(strcmp(argv[i], "-help")==0) {
      /* was already handled in first argument scan */;
-   } else if(strcmp(argv[i], "-V")==0 || strcmp(argv[i], "-volid")==0) {
+   } else if(strcmp(argv[i], "-V")==0 || strcmp(argv[i], "-volid")==0 ||
+             strcmp(argv[i], "-volset")==0 ||
+             strcmp(argv[i], "-P")==0 || strcmp(argv[i], "-publisher")==0 ||
+             strcmp(argv[i], "-A")==0 || strcmp(argv[i], "-appid")==0 ||
+             strcmp(argv[i], "-sysid")==0 ||
+             strcmp(argv[i], "-biblio")==0 ||
+             strcmp(argv[i], "-copyright")==0 ||
+             strcmp(argv[i], "-abstract")==0 ) {
      if(i+1>=argc)
        goto not_enough_args;
      i++;
-     ret= Xorriso_option_volid(xorriso, argv[i], 0);
-     if(ret<=0)
-       goto problem_handler_2;
-   } else if(strcmp(argv[i], "-volset")==0) {
-     if(i+1>=argc)
-       goto not_enough_args;
-     i++;
-     ret= Xorriso_option_volid(xorriso, argv[i], 0);
-     if(ret<=0)
-       goto problem_handler_2;
-   } else if(strcmp(argv[i], "-P")==0 || strcmp(argv[i], "-publisher")==0) {
-     if(i+1>=argc)
-       goto not_enough_args;
-     i++;
-     ret= Xorriso_option_publisher(xorriso, argv[i], 0);
-     if(ret<=0)
-       goto problem_handler_2;
-   } else if(strcmp(argv[i], "-A")==0 || strcmp(argv[i], "-appid")==0) {
-     if(i+1>=argc)
-       goto not_enough_args;
-     i++;
-     ret= Xorriso_option_application_id(xorriso, argv[i], 0);
-     if(ret<=0)
-       goto problem_handler_2;
-   } else if(strcmp(argv[i], "-sysid")==0) {
-     if(i+1>=argc)
-       goto not_enough_args;
-     i++;
-     ret= Xorriso_option_system_id(xorriso, argv[i], 0);
+     ret= 1;
+     if(strcmp(argv[i - 1], "-V")==0 || strcmp(argv[i - 1], "-volid")==0)
+       ret= Xorriso_option_volid(xorriso, argv[i], 0);
+     else if(strcmp(argv[i - 1], "-volset")==0)
+       ret= Xorriso_option_volset_id(xorriso, argv[i], 0);
+     else if(strcmp(argv[i - 1], "-P")==0 ||
+             strcmp(argv[i - 1], "-publisher")==0)
+       ret= Xorriso_option_publisher(xorriso, argv[i], 0);
+     else if(strcmp(argv[i - 1], "-A")==0 || strcmp(argv[i - 1], "-appid")==0)
+       ret= Xorriso_option_application_id(xorriso, argv[i], 0);
+     else if(strcmp(argv[i - 1], "-sysid")==0)
+       ret= Xorriso_option_system_id(xorriso, argv[i], 0);
+     else if(strcmp(argv[i - 1], "-biblio")==0)
+       ret= Xorriso_option_biblio_file(xorriso, argv[i], 0);
+     else if(strcmp(argv[i - 1], "-copyright")==0)
+       ret= Xorriso_option_copyright_file(xorriso, argv[i], 0);
+     else if(strcmp(argv[i - 1], "-abstract")==0)
+       ret= Xorriso_option_abstract_file(xorriso, argv[i], 0);
      if(ret<=0)
        goto problem_handler_2;
    } else if(strcmp(argv[i], "-m")==0 || strcmp(argv[i], "-exclude")==0 ||
@@ -991,8 +1102,9 @@ not_enough_args:;
              strcmp(argv[i], "-boot-info-table")==0 ||
              strncmp(argv[i], "isolinux_mbr=", 13)==0 ||
              strcmp(argv[i], "-eltorito-alt-boot")==0 ||
-             strcmp(argv[i], "--protective-msdos-label")==0) {
-     boot_opt_list[boot_opt_count++]= i;
+             strcmp(argv[i], "--protective-msdos-label")==0 ||
+             strcmp(argv[i], "--boot-catalog-hide")==0) {
+     delay_opt_list[delay_opt_count++]= i;
    } else if(strcmp(argv[i], "-b") == 0 ||
              strcmp(argv[i], "-eltorito-boot") == 0 ||
              strcmp(argv[i], "--efi-boot") == 0 ||
@@ -1005,7 +1117,7 @@ not_enough_args:;
              strcmp(argv[i], "-isohybrid-mbr")==0) {
      if(i+1>=argc)
        goto not_enough_args;
-     boot_opt_list[boot_opt_count++]= i;
+     delay_opt_list[delay_opt_count++]= i;
      i++;
    } else if(strncmp(argv[i], "--modification-date=", 20)==0) {
      ret= Xorriso_option_volume_date(xorriso, "uuid", argv[i] + 20, 0);
@@ -1053,6 +1165,33 @@ not_enough_args:;
      Xorriso_relax_compliance(xorriso, "no_force_dots", 0);
    } else if(strcmp(argv[i], "-allow-lowercase") == 0) {
      Xorriso_relax_compliance(xorriso, "lowercase", 0);
+
+   } else if(strcmp(argv[i], "-hide") == 0 ||
+             strcmp(argv[i], "-hide-list") == 0 ||
+             strcmp(argv[i], "-hide-joliet") == 0 ||
+             strcmp(argv[i], "-hide-joliet-list") == 0) {
+     if(i+1>=argc)
+       goto not_enough_args;
+     i++;
+     /* was already handled in first argument scan */;
+   } else if(strcmp(argv[i], "-dir-mode") == 0) {
+     if(i+1>=argc)
+       goto not_enough_args;
+     i++;
+     ret= Xorriso_convert_modstring(xorriso, "-as mkisofs -dir-mode",
+                                    argv[i], &mode_and, &mode_or, 0);
+     if(ret<=0)
+       goto problem_handler_2;
+     dir_mode= mode_or;
+   } else if(strcmp(argv[i], "-file-mode") == 0) {
+     if(i+1>=argc)
+       goto not_enough_args;
+     i++;
+     ret= Xorriso_convert_modstring(xorriso, "-as mkisofs -file-mode",
+                                    argv[i], &mode_and, &mode_or, 0);
+     if(ret<=0)
+       goto problem_handler_2;
+     file_mode= mode_or;
    } else if(argv[i][0]=='-' && argv[i][1]!=0) {
      sprintf(xorriso->info_text, "-as %s: Unknown option %s",
              whom, Text_shellsafe(argv[i], sfe, 0));
@@ -1107,11 +1246,30 @@ problem_handler_2:;
      goto ex;
  }
  if(lower_r) {
+   static char *lower_r_args[3]= {"/", "-exec", "mkisofs_r"};
    zero= 0;
    ret= Xorriso_option_find(xorriso, 3, lower_r_args, &zero, 2);
    if(ret<=0)
      goto ex;
  }
+ if(dir_mode >= 0) {
+   static char *dir_mode_args[6]= {"/", "-type", "d", "-exec", "chmod", ""};
+   zero= 0;
+   sprintf(sfe, "0%o", (unsigned int) dir_mode);
+   dir_mode_args[5]= sfe;
+   ret= Xorriso_option_find(xorriso, 6, dir_mode_args, &zero, 2);
+   if(ret<=0)
+     goto ex;
+ }
+ if(file_mode >= 0) {
+   static char *file_mode_args[6]= {"/", "-type", "f", "-exec", "chmod", ""};
+   zero= 0;
+   sprintf(sfe, "0%o", (unsigned int) file_mode);
+   file_mode_args[5]= sfe;
+   ret= Xorriso_option_find(xorriso, 6, file_mode_args, &zero, 2);
+   if(ret<=0)
+     goto ex;
+ }
 
  for(j= 0; j < weight_count; j++) {
    i= weight_list[j];
@@ -1131,8 +1289,8 @@ problem_handler_2:;
  }
 
  /* After all pathspecs are added: perform boot related options */
- for(j= 0; j < boot_opt_count; j++) {
-   i= boot_opt_list[j];
+ for(j= 0; j < delay_opt_count; j++) {
+   i= delay_opt_list[j];
    if(strcmp(argv[i], "-no-emul-boot")==0) {
      no_emul_boot= 1;
    } else if(strcmp(argv[i], "-boot-info-table")==0) {
@@ -1170,6 +1328,7 @@ problem_handler_2:;
          goto problem_handler_boot;
      }
      xorriso->keep_boot_image= 0;
+     with_boot_image= 1;
    } else if(strcmp(argv[i], "-c") == 0 ||
              strcmp(argv[i], "-eltorito-catalog") == 0) {
      if(i+1>=argc)
@@ -1182,6 +1341,8 @@ problem_handler_2:;
                     + strlen(xorriso->boot_image_cat_path), argv[i], 0);
      if(ret <= 0)
        goto ex;
+     if(with_cat_path == 0)
+       with_cat_path= 1;
    } else if(strcmp(argv[i], "-boot-load-size") == 0) {
      if(i+1>=argc)
        goto not_enough_args;
@@ -1212,6 +1373,8 @@ problem_handler_2:;
        xorriso->system_area_options= (xorriso->system_area_options & ~3) | 2;
    } else if(strcmp(argv[i], "--protective-msdos-label")==0) {
      xorriso->system_area_options= (xorriso->system_area_options & ~3) | 1;
+   } else if(strcmp(argv[i], "--boot-catalog-hide")==0) {
+     xorriso->boot_image_cat_hidden|= 3;
    }
  continue; /* regular bottom of loop */
 problem_handler_boot:;
@@ -1222,11 +1385,21 @@ problem_handler_boot:;
  continue;
    goto ex;
  }
+ if(with_boot_image && with_cat_path == 0)
+   strcpy(xorriso->boot_image_cat_path, "/boot.catalog");
  if(xorriso->boot_image_bin_path[0]) {
    ret= Xorriso_genisofs_add_boot(xorriso, whom, &option_b, &no_emul_boot, 0);
    if(ret <= 0)
      goto ex;
  }
+ /* The boot catalog has to be hidden separately */
+ if(xorriso->boot_image_cat_path[0]) {
+   ret= Xorriso_path_is_hidden(xorriso, xorriso->boot_image_cat_path, 0);
+   if(ret > 0)
+     xorriso->boot_image_cat_hidden|= ret;
+   else if(ret < 0)
+     was_failure= 1;
+ }
 
  ret= !was_failure;
 ex:;
@@ -1237,8 +1410,8 @@ ex:;
    Xorriso_option_rollback(xorriso, 0);
  if(weight_list != NULL)
    free(weight_list);
- if(boot_opt_list != NULL)
-   free(boot_opt_list);
+ if(delay_opt_list != NULL)
+   free(delay_opt_list);
  return(ret);
 }
 
