@@ -85,6 +85,7 @@ int Xorriso_create_empty_iso(struct XorrisO *xorriso, int flag)
    Xorriso_destroy_hln_array(xorriso, 0);
    xorriso->loaded_volid[0]= 0;
    xorriso->volset_change_pending= 0;
+   xorriso->boot_count= 0;
    xorriso->no_volset_present= 0;
  }
 
@@ -108,6 +109,7 @@ int Xorriso_create_empty_iso(struct XorrisO *xorriso, int flag)
  xorriso->in_sector_map= NULL;
  Xorriso_update_volid(xorriso, 0);
  xorriso->volset_change_pending= 0;
+ xorriso->boot_count= 0;
  xorriso->no_volset_present= 0;
  return(1);
 }
@@ -283,13 +285,11 @@ int Xorriso_pvd_info(struct XorrisO *xorriso, int flag)
  Xorriso_result(xorriso,0);
  sprintf(msg, "System Id    : %s\n", xorriso->system_id);
  Xorriso_result(xorriso,0);
- sprintf(msg, "Copyright Id : %s\n",
-         un0(iso_image_get_copyright_file_id(image)));
+ sprintf(msg, "CopyrightFile: %s\n", xorriso->copyright_file);
  Xorriso_result(xorriso,0);
- sprintf(msg, "Abstract Id  : %s\n",
-         un0(iso_image_get_abstract_file_id(image)));
+ sprintf(msg, "Abstract File: %s\n", xorriso->abstract_file);
  Xorriso_result(xorriso,0);
- sprintf(msg, "Biblio Id    : %s\n", un0(iso_image_get_biblio_file_id(image)));
+ sprintf(msg, "Biblio File  : %s\n", xorriso->biblio_file);
  Xorriso_result(xorriso,0);
  return(1);
 }
@@ -458,7 +458,7 @@ int Xorriso_boot_image_status(struct XorrisO *xorriso, char *filter, FILE *fp,
 {
  int ret, i, num_boots, hflag;
  int bin_path_in_use= 0, is_default, no_defaults;
- char sfe[5*SfileadrL], path[SfileadrL], *form= "any", *line;
+ char sfe[5*SfileadrL], path[SfileadrL], *form= "any", *line, *hpt;
  struct burn_drive_info *dinfo;
  struct burn_drive *drive;
  IsoImage *image= NULL;
@@ -506,6 +506,13 @@ int Xorriso_boot_image_status(struct XorrisO *xorriso, char *filter, FILE *fp,
    if(!(is_default && no_defaults))
      Xorriso_status_result(xorriso,filter,fp,flag&2);
  }
+ if(bin_path_in_use) {
+   is_default= !xorriso->boot_image_cat_hidden;
+   hpt= Xorriso__hide_mode_text(xorriso->boot_image_cat_hidden & 3, 0);
+   sprintf(line, "-boot_image %s cat_hidden=%s\n", form, hpt);
+   if(!(is_default && no_defaults))
+     Xorriso_status_result(xorriso,filter,fp,flag&2);
+ }
 
  if(xorriso->boot_count > 0) {
 
