@@ -57,6 +57,18 @@ int Xorriso_option_abort_on(struct XorrisO *xorriso, char *severity, int flag)
 }
 
 
+/* Option -abstract_file */
+int Xorriso_option_abstract_file(struct XorrisO *xorriso, char *name, int flag)
+{
+ if(Xorriso_check_name_len(xorriso, name,
+                           (int) sizeof(xorriso->abstract_file),
+                           "-abstract_file", 0) <= 0)
+   return(0);
+ strcpy(xorriso->abstract_file, name);
+ Xorriso_set_change_pending(xorriso, 1);
+ return(1);
+}
+
 /* Option -acl "on"|"off" */
 int Xorriso_option_acl(struct XorrisO *xorriso, char *mode, int flag)
 {
@@ -427,6 +439,18 @@ int Xorriso_option_ban_stdio_write(struct XorrisO *xorriso, int flag)
 }
 
 
+/* Option -biblio_file */
+int Xorriso_option_biblio_file(struct XorrisO *xorriso, char *name, int flag)
+{
+ if(Xorriso_check_name_len(xorriso, name, (int) sizeof(xorriso->biblio_file),
+                           "-biblio_file", 0) <= 0)
+   return(0);
+ strcpy(xorriso->biblio_file, name);
+ Xorriso_set_change_pending(xorriso, 1);
+ return(1);
+}
+
+
 /* Option -blank and -format */
 /* @param flag bit0= format rather than blank
    @return <=0 error , 1 success, 2 revoked by -reassure 
@@ -624,6 +648,13 @@ treatment_patch:;
    if(ret <= 0)
      return(ret);
 
+ } else if(strncmp(treatpt, "cat_hidden=", 11) == 0) {
+   ret= Xorriso__hide_mode(treatpt + 11, 0);
+   if(ret >= 0)
+     xorriso->boot_image_cat_hidden= ret;
+   else
+     was_ok= 0;
+
  } else if(strncmp(treatpt, "dir=", 4) == 0) {
    if(strcmp(formpt, "isolinux")==0) {
      /* ISOLINUX */
@@ -1673,6 +1704,19 @@ int Xorriso_option_compliance(struct XorrisO *xorriso, char *mode,
 }
 
 
+/* Option -copyright_file */
+int Xorriso_option_copyright_file(struct XorrisO *xorriso, char *name, int flag)
+{
+ if(Xorriso_check_name_len(xorriso, name,
+                           (int) sizeof(xorriso->copyright_file),
+                           "-copyright_file", 0) <= 0)
+   return(0);
+ strcpy(xorriso->copyright_file, name);
+ Xorriso_set_change_pending(xorriso, 1);
+ return(1);
+}
+
+
 /* Option -cpr alias -cpri */
 int Xorriso_option_cpri(struct XorrisO *xorriso, int argc, char **argv,
                          int *idx, int flag)
