@@ -686,6 +686,33 @@ not_enough_arguments:;
      Findjob_set_filter_filter(job, -1, 0);
    } else if(strcmp(argv[i], "-has_md5")==0) {
      Findjob_set_prop_filter(job, 15, 1, 0);
+   } else if(strcmp(argv[i], "-disk_name")==0) {
+     if(i+1>=end_idx)
+       goto not_enough_arguments;
+     i++;
+     ret= Findjob_set_name_expr(job, argv[i], 2);
+     if(ret<=0) {
+       sprintf(xorriso->info_text,
+               "-find[ix]: cannot set -disk_name expression %s",
+               Text_shellsafe(argv[i], sfe, 0));
+       goto sorry_ex;
+     }
+   } else if(strcmp(argv[i], "-hidden")==0) {
+     if(i + 1 >= end_idx)
+       goto not_enough_arguments;
+     i+= 1;
+     type= Xorriso__hide_mode(argv[i], 0);
+     if(type < 0) {
+       sprintf(xorriso->info_text, "-findi: -hidden : unknown hide state %s",
+               Text_shellsafe(argv[i], sfe, 0));
+       goto sorry_ex;
+     } else {
+       ret= Findjob_set_test_hidden(job, type, 0);
+       if(ret <= 0) {
+         sprintf(xorriso->info_text, "-findi: cannot setup -hidden test");
+         goto sorry_ex;
+       }
+     }
    } else if(strcmp(argv[i], "-true") == 0) {
      ret= Findjob_set_false(job, -1, 0);
    } else if(strcmp(argv[i], "-false") == 0) {
@@ -937,6 +964,17 @@ not_enough_exec_arguments:;
        i+= 1;
        sscanf(argv[i], "%d", &type);
        Findjob_set_action_type(job, 38, type, 0);
+     } else if(strcmp(cpt, "hide")==0) {
+       if(i+1>=end_idx)
+         goto not_enough_exec_arguments;
+       i++;
+       type= Xorriso__hide_mode(argv[i], 0);
+       if(type < 0) {
+         sprintf(xorriso->info_text, "-find -exec hide: unknown hide state %s",
+                 Text_shellsafe(argv[i], sfe, 0));
+         goto sorry_ex;
+       }
+       Findjob_set_action_type(job, 39, type, 0);
      } else {
        sprintf(xorriso->info_text, "-find -exec: unknown action %s",
                Text_shellsafe(argv[i], sfe, 0));
@@ -1330,13 +1368,20 @@ int Xorriso_option_help(struct XorrisO *xorriso, int flag)
 "                 Specifies the system id for the System Area. (32 chars)",
 "  -volume_date type timestring",
 "                 Specifies volume timestamps. [\"c\",\"m\",\"x\",\"f\",\"uuid\"]", 
+"  -copyright_file name",
+"                 Specifies the name of the Copyright File. (37 chars)",
+"  -biblio_file name",
+"                 Specifies the name of the Bibliographic File. (37 chars)",
+"  -abstract_file name",
+"                 Specifies the name of the Abstract File. (37 chars)",
 "  -joliet \"on\"|\"off\"",
 "                 Generate Joliet info additional to Rock Ridge info.",
 "  -compliance rule[:rule...]",
 "                 Allow more or less harmless deviations from strict standards",
 "                 compliance.",
 "  -boot_image \"any\"|\"isolinux\"|\"grub\"",
-"              \"discard\"|\"keep\"|\"patch\"|\"dir=\"|\"bin_path=\"|\"cat_path=\"",
+"              |\"discard\"|\"keep\"|\"patch\"|\"dir=\"|\"bin_path=\"",
+"              |\"cat_path=\"|\"cat_hidden=on|iso_rr|joliet|off\"",
 "              |\"load_size=\"|\"system_area=\"|\"partition_table=on|off\"",
 "                 Whether to discard or keep an exiting El Torito boot image.",
 "                 ISOLINUX can be made bootable by dir=/ or dir=/isolinux",
@@ -1466,13 +1511,17 @@ int Xorriso_option_help(struct XorrisO *xorriso, int flag)
 "                 access time, modification time, both times.",
 "  -alter_date_r type timestring iso_rr_path [***]",
 "                 Like -alter_date but affecting all files below directories.",
+"  -hide on|iso_rr|joliet|off iso_rr_path [***]",
+"                 Keep names of files out of directory tree, but store their",
+"                 data content in the image.",
 "  -find iso_rr_path [test [op] [test ...]] [-exec action [params]]",
 "                 performs an action on files below the given directory in",
 "                 the ISO image. Tests:",
-"                   -name pattern, -wholename pattern, -type b|c|d|p|f|l|s|e,",
-"                   -pending_data, -lba_range start count, -damaged,",
-"                   -has_acl, -has_xattr, -has_aaip, -has_filter, -has_md5",
-"                   -has_any_xattr, -prune, -decision yes|no, -true, -false",
+"                   -name pattern, -wholename pattern, -disk_name pattern,",
+"                   -type b|c|d|p|f|l|s|e, -pending_data, -hidden,",
+"                   -lba_range start count, -damaged, -has_acl, -has_xattr,",
+"                   -has_aaip, -has_filter, -has_md5, -has_any_xattr,",
+"                   -prune, -decision yes|no, -true, -false",
 "                 Operators: -not, -or, -and, -sub, (, -subend, ),",
 "                   -if, -then, -elseif, -else, -endif",
 "                 Action may be one of: echo, chown, chown_r, chgrp, chgrp_r",
@@ -1480,7 +1529,7 @@ int Xorriso_option_help(struct XorrisO *xorriso, int flag)
 "                   rm, rm_r, compare, update, report_damage, report_lba,",
 "                   getfacl, setfacl, getfattr, setfattr, get_any_xattr,",
 "                   get_md5, check_md5, make_md5, set_filter, show_stream,",
-"                   mkisofs_r, find.",
+"                   mkisofs_r, hide, find.",
 "                 params are their arguments except iso_rr_path.",
 "  -mkdir iso_rr_path [...]",
 "                 Create empty directories if they do not exist yet.",
@@ -1698,6 +1747,8 @@ int Xorriso_option_help(struct XorrisO *xorriso, int flag)
 "                -no-emul-boot|-b|-c|-boot-info-table|-boot-load-size|-G]",
 "              Perform some mkisofs gestures, understand pathspecs as mkisofs",
 "              does. Commit happens outside emulation at usual occasions.",
+"  -read_mkisofsrc",
+"              Read and interpret the .mkisofsrc configuration file.",
 "  -as cdrecord [-help|-v|dev=|speed=|blank=|fs=|-eject|-atip|padsize=|-multi]",
 "               path|-",
 "              Perform some cdrecord gestures, eventually write at most one",
@@ -1827,6 +1878,46 @@ int Xorriso_option_help(struct XorrisO *xorriso, int flag)
 }
 
 
+/* Option -hide */
+int Xorriso_option_hide(struct XorrisO *xorriso, char *hide_state,
+                        int argc, char **argv, int *idx, int flag)
+{
+ int i, ret, end_idx, optc= 0, was_failure= 0, fret, hide_mode;
+ char **optv= NULL;
+
+ ret= Xorriso_opt_args(xorriso, "-hide", argc, argv, *idx, &end_idx, &optc,
+                       &optv, 0);
+ if(ret<=0)
+   goto ex;
+ hide_mode= Xorriso__hide_mode(hide_state, 0);
+ if(hide_mode < 0) {
+   sprintf(xorriso->info_text, "-hide : unknown hide state ");
+   Text_shellsafe(hide_state, xorriso->info_text, 1);
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+   goto ex;
+ }
+ for(i= 0; i<optc; i++) {
+   ret= Xorriso_set_hidden(xorriso, NULL, optv[i], hide_mode, 0);
+   if(ret>0 && !xorriso->request_to_abort)
+ continue; /* regular bottom of loop */
+
+   was_failure= 1;
+   fret= Xorriso_eval_problem_status(xorriso, ret, 1|2);
+   if(fret>=0)
+ continue;
+   ret= 0; goto ex;
+ }
+ ret= 1;
+ex:;
+ (*idx)= end_idx;
+ Xorriso_opt_args(xorriso, "-hide", argc, argv, *idx, &end_idx, &optc, &optv,
+                  256);
+ if(ret<=0)
+   return(ret);
+ return(!was_failure);
+}
+
+
 /* Option -history */
 int Xorriso_option_history(struct XorrisO *xorriso, char *line, int flag)
 {
