@@ -154,15 +154,17 @@ int Xorriso_option_path_list(struct XorrisO *xorriso, char *adr, int flag)
      if(ret<=0 || xorriso->request_to_abort)
        goto problem_handler;
      insertcount++;
-   }
 
- continue; /* regular bottom of loop */
+   continue; /* regular bottom of loop */
 problem_handler:;
-   was_failure= 1;
-   fret= Xorriso_eval_problem_status(xorriso, ret, 1|2);
-   if(fret>=0)
- continue;
-   goto ex;
+     was_failure= 1;
+     fret= Xorriso_eval_problem_status(xorriso, ret, 1|2);
+     if(fret>=0)
+   continue;
+     if(ret > 0)
+       ret= 0;
+     goto ex;
+   }
  }
  ret= 1;
 ex:;
@@ -250,7 +252,8 @@ int Xorriso_option_print_size(struct XorrisO *xorriso, int flag)
    fd= xorriso->dev_fd_1;
    if(fd<0)
      fd= 1;
-   write(fd, xorriso->result_line, strlen(xorriso->result_line));
+   ret= write(fd, xorriso->result_line, strlen(xorriso->result_line));
+   /* (result of write intentionally ignored) */
    fsync(fd);
  } else {
    sprintf(xorriso->result_line,"Image size   : %ds\n", ret);
@@ -346,6 +349,15 @@ int Xorriso_option_pwdx(struct XorrisO *xorriso, int flag)
 }
 
 
+int Xorriso_option_read_mkisofsrc(struct XorrisO *xorriso, int flag)
+{
+ int ret;
+
+ ret= Xorriso_read_mkisofsrc(xorriso, 0);
+ return(ret);
+}
+
+
 /* Option -reassure "on"|"tree"|"off" */
 int Xorriso_option_reassure(struct XorrisO *xorriso, char *mode, int flag)
 {
@@ -1558,6 +1570,8 @@ int Xorriso_option_version(struct XorrisO *xorriso, int flag)
 
 
 /* Option -volid */
+/* @param flag bit0= do not warn of problematic volid
+*/
 int Xorriso_option_volid(struct XorrisO *xorriso, char *volid, int flag)
 {
  int warn_shell= 0, warn_ecma= 0, i, ret;
@@ -1576,17 +1590,17 @@ int Xorriso_option_volid(struct XorrisO *xorriso, char *volid, int flag)
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
    return(0);
  }
- if(warn_shell) {
+ if(warn_shell && !(flag & 1)) {
    sprintf(xorriso->info_text,
            "-volid text problematic as automatic mount point name");
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "WARNING", 0);
  }
- if(xorriso->do_joliet && strlen(volid)>16) {
+ if(xorriso->do_joliet && strlen(volid)>16 && !(flag & 1)) {
    sprintf(xorriso->info_text,
            "-volid text is too long for Joliet (%d > 16)",(int) strlen(volid));
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "WARNING", 0);
  }
- if(warn_ecma) {
+ if(warn_ecma && !(flag & 1)) {
    sprintf(xorriso->info_text,
           "-volid text does not comply to ISO 9660 / ECMA 119 rules");
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "WARNING", 0);
