@@ -77,6 +77,7 @@ int Xorriso_end_idx(struct XorrisO *xorriso,
                bit6= with bit5 allow 0 matches if pattern is a constant
                bit7= silently tolerate empty argument list
                bit8= free the eventually allocated sub_vector
+               bit9= always expand wildcards
 */
 int Xorriso_opt_args(struct XorrisO *xorriso, char *cmd,
                      int argc, char **argv, int idx,
@@ -87,9 +88,9 @@ int Xorriso_opt_args(struct XorrisO *xorriso, char *cmd,
  off_t mem= 0;
 
  if(flag&2)
-   do_expand= xorriso->do_disk_pattern==1 && !(flag&4);
+   do_expand= (xorriso->do_disk_pattern==1 && !(flag&4)) || (flag & 512);
  else
-   do_expand= xorriso->do_iso_rr_pattern==1 && !(flag&4);
+   do_expand= (xorriso->do_iso_rr_pattern==1 && !(flag&4)) || (flag & 512);
  if(flag&256) {
    if(*optv<argv || *optv>=argv+argc)
      Sfile_destroy_argv(optc, optv, 0);
@@ -448,14 +449,16 @@ int Xorriso_count_args(struct XorrisO *xorriso, int argc, char **argv,
     "ban_stdio_write","close_filter_list","commit","devices","end",
     "for_backup", "help",
     "list_formats","no_rc","print_size","pvd_info","pwd","pwdi","pwdx",
-    "rollback","rollback_end","tell_media_space","toc","version",
+    "read_mkisofsrc","rollback","rollback_end",
+    "tell_media_space","toc","version",
     ""
  };
  static char arg1_commands[][40]= {
     "abort_on","acl","add_plainly","application_id","auto_charset",
-    "backslash_codes","blank",
+    "abstract_file",
+    "backslash_codes","blank","biblio_file",
     "calm_drive","cd","cdi","cdx","charset","close",
-    "commit_eject","compliance",
+    "commit_eject","compliance","copyright_file",
     "dev","dialog","disk_dev_ino","disk_pattern","dummy","dvd_obs","eject",
     "iso_rr_pattern","follow","format","fs","gid","grow_blindly","hardlinks",
     "history","indev","in_charset","joliet",
@@ -492,7 +495,7 @@ int Xorriso_count_args(struct XorrisO *xorriso, int argc, char **argv,
     "du","dui","dus","dusi","dux","dusx","external_filter","extract_l",
     "file_size_limit","find","findi","finds","findx",
     "getfacl","getfacli","getfacl_r","getfacl_ri",
-    "getfattr","getfattri","getfattr_r","getfattr_ri",
+    "getfattr","getfattri","getfattr_r","getfattr_ri","hide",
     "ls","lsi","lsl","lsli","lsd","lsdi","lsdl","lsdli",
     "lsx","lslx","lsdx","lsdlx","map_l","mv","mvi","mkdir","mkdiri",
     "not_paths","rm","rmi","rm_r","rm_ri","rmdir","rmdiri","update_l",
@@ -624,6 +627,10 @@ next_command:;
    (*idx)++;
    ret= Xorriso_option_abort_on(xorriso, arg1, 0);
 
+ } else if(strcmp(cmd,"abstract_file")==0) { 
+   (*idx)++;
+   Xorriso_option_abstract_file(xorriso, arg1, 0);
+
  } else if(strcmp(cmd,"acl")==0) {
    (*idx)++;
    ret= Xorriso_option_acl(xorriso, arg1, 0);
@@ -662,6 +669,10 @@ next_command:;
  } else if(strcmp(cmd,"ban_stdio_write")==0) {
    ret= Xorriso_option_ban_stdio_write(xorriso, 0);
 
+ } else if(strcmp(cmd,"biblio_file")==0) { 
+   (*idx)++;
+   Xorriso_option_biblio_file(xorriso, arg1, 0);
+
  } else if(strcmp(cmd,"blank")==0) {
    (*idx)++;
    ret= Xorriso_option_blank(xorriso, arg1, 0);
@@ -751,6 +762,10 @@ next_command:;
    (*idx)++;
    Xorriso_option_compliance(xorriso, arg1, 0);
 
+ } else if(strcmp(cmd,"copyright_file")==0) { 
+   (*idx)++;
+   Xorriso_option_copyright_file(xorriso, arg1, 0);
+
  } else if(strcmp(cmd,"cpr")==0 || strcmp(cmd,"cpri")==0) {
    ret= Xorriso_option_cpri(xorriso, argc, argv, idx, 0);
 
@@ -911,6 +926,10 @@ next_command:;
  } else if(strcmp(cmd,"help")==0) {
    Xorriso_option_help(xorriso,0);
 
+ } else if(strcmp(cmd,"hide")==0) {
+   (*idx)+= 1;
+   ret= Xorriso_option_hide(xorriso, arg1, argc, argv, idx, 1);   
+
  } else if(strcmp(cmd,"history")==0) {
    /* add to readline history */
    (*idx)++;
@@ -1131,6 +1150,9 @@ next_command:;
    (*idx)++;
    ret= Xorriso_option_path_list(xorriso, arg1, 1);
 
+ } else if(strcmp(cmd,"read_mkisofsrc")==0) {
+   ret= Xorriso_option_read_mkisofsrc(xorriso, 0);
+
  } else if(strcmp(cmd,"reassure")==0) {
    (*idx)++;
    ret= Xorriso_option_reassure(xorriso, arg1, 0);
@@ -1589,6 +1611,135 @@ ex:;
 }
 
 
+int Xorriso_read_as_mkisofsrc(struct XorrisO *xorriso, char *path, int flag)
+{
+ int ret, linecount= 0;
+ FILE *fp= NULL;
+ char *sret, line[SfileadrL], *cpt, *wpt;
+
+ ret= Xorriso_afile_fopen(xorriso, path, "rb", &fp, 1 | 2);
+ if(ret <= 0)
+   {ret= 0; goto ex;}
+ while(1) {
+   sret= Sfile_fgets_n(line, SfileadrL - 1, fp, 0);
+   if(sret == NULL) {
+     if(ferror(fp))
+       {ret= 0; goto ex;}
+ break;
+   }
+   linecount++;
+   
+   /* Interpret line */
+   if(line[0] == 0 || line[0] == '#')
+ continue;
+   cpt= strchr(line, '=');
+   if(cpt == NULL) {
+
+     /* >>> ??? complain ? abort reading ? */;
+
+ continue;
+   }
+   *cpt= 0;
+   /* Names are not case sensitive */
+   for(wpt= line; wpt < cpt; wpt++)
+     if(*wpt >= 'a' && *wpt <= 'z')
+       *wpt= toupper(*wpt);
+   /* Remove trailing whitespace from name */
+   for(wpt= cpt - 1; wpt >= line ; wpt--)
+     if(*wpt == ' ' || *wpt == '\t')
+       *wpt= 0;
+     else
+   break;
+   /* Remove trailing whitespace from value */
+   for(wpt= cpt + 1 + strlen(cpt + 1) - 1; wpt >= cpt; wpt--)
+      if(*wpt == ' ' || *wpt == '\t')
+       *wpt= 0;
+     else
+   break;
+   /* Remove leading whitespace from value */
+   for(cpt++; *cpt == ' ' || *cpt == '\t'; cpt++);
+   
+   if(strcmp(line, "APPI") == 0) {
+     ret= Xorriso_option_application_id(xorriso, cpt, 0);
+   } else if(strcmp(line, "COPY") == 0) {
+     ret= Xorriso_option_copyright_file(xorriso, cpt, 0);
+   } else if(strcmp(line, "ABST") == 0) {
+     ret= Xorriso_option_abstract_file(xorriso, cpt, 0);
+   } else if(strcmp(line, "BIBL") == 0) {
+     ret= Xorriso_option_biblio_file(xorriso, cpt, 0);
+   } else if(strcmp(line, "PREP") == 0) {
+     /* Not planned to be implemented. Preparer is xorriso. */
+     ret= 1;
+   } else if(strcmp(line, "PUBL") == 0) {
+     ret= Xorriso_option_publisher(xorriso, cpt, 0);
+   } else if(strcmp(line, "SYSI") == 0) {
+     ret= Xorriso_option_system_id(xorriso, cpt, 0);
+   } else if(strcmp(line, "VOLI") == 0) {
+     ret= Xorriso_option_volid(xorriso, cpt, 1);
+   } else if(strcmp(line, "VOLS") == 0) {
+     ret= Xorriso_option_volset_id(xorriso, cpt, 0);
+   } else if(strcmp(line, "HFS_TYPE") == 0) {
+     /* Not planned to be implemented */
+     ret= 1;
+   } else if(strcmp(line, "HFS_CREATOR") == 0) {
+     /* Not planned to be implemented */
+     ret= 1;
+   } else {
+
+     /* >>> ??? complain ? abort reading ? */;
+
+   }
+ }
+ xorriso->mkisofsrc_done= 1;
+ ret= 1;
+ex:
+ if(fp != NULL)
+   fclose(fp);
+ return(ret);
+}
+
+
+/* ./.mkisofsrc , getenv("MKISOFSRC") ,
+   $HOME/.mkisofsrc , $(basename $0)/.mkisofsrc
+ */
+int Xorriso_read_mkisofsrc(struct XorrisO *xorriso, int flag)
+{
+ char path[SfileadrL], *cpt;
+ int ret;
+
+ ret= Xorriso_read_as_mkisofsrc(xorriso, "./.mkisofsrc", 0);
+ if(ret > 0)
+   return(ret);
+ cpt= getenv("MKISOFSRC");
+ if(cpt != NULL) {
+   strncpy(path, cpt, SfileadrL - 1);
+   path[SfileadrL - 1]= 0;
+   ret= Xorriso_read_as_mkisofsrc(xorriso, path, 0);
+   if(ret > 0)
+     return(ret);
+ }
+ cpt= getenv("HOME");
+ if(cpt != NULL) {
+   strncpy(path, cpt, SfileadrL - 1 - 11);
+   path[SfileadrL - 1 - 11]= 0;
+   strcat(path, "/.mkisofsrc");
+   ret= Xorriso_read_as_mkisofsrc(xorriso, path, 0);
+   if(ret > 0)
+     return(ret);
+ }
+ strcpy(path, xorriso->progname);
+ cpt= strrchr(path, '/');
+ if(cpt != NULL) {
+   strcpy(cpt + 1, ".mkisofsrc");
+   ret= Xorriso_read_as_mkisofsrc(xorriso, path, 0);
+   if(ret > 0)
+     return(ret);
+ }
+ /* no .mkisofsrc file found */
+ return(2); 
+}
+
+
 int Xorriso_read_rc(struct XorrisO *xorriso, int flag)
 {
  int ret,i,was_failure= 0,fret;
@@ -1613,6 +1764,11 @@ int Xorriso_read_rc(struct XorrisO *xorriso, int flag)
  continue;
    return(ret);
  }
+ if(xorriso->argument_emulation == 1 && !xorriso->mkisofsrc_done) {
+   ret= Xorriso_read_mkisofsrc(xorriso, 0);
+   if(ret <= 0)
+     was_failure= 1;
+ }
  return(!was_failure);
 }
 
@@ -1875,6 +2031,28 @@ int Xorriso_path_is_excluded(struct XorrisO *xorriso, char *path, int flag)
 }
 
 
+int Xorriso_path_is_hidden(struct XorrisO *xorriso, char *path, int flag)
+{
+ int ret, hide_attrs= 0;
+
+ ret= Exclusions_match(xorriso->iso_rr_hidings, path, 0);
+ if(ret < 0) {
+failure:;
+   sprintf(xorriso->info_text, "Error during disk file hiding decision");
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FATAL", 0);
+   return(-1);
+ }
+ if(ret > 0)
+   hide_attrs|= 1;
+ ret= Exclusions_match(xorriso->joliet_hidings, path, 0);
+ if(ret < 0)
+   goto failure;
+ if(ret > 0)
+   hide_attrs|= 2;
+ return(hide_attrs);
+}
+
+
 /* Normalize ACL and sort apart "access" ACL from "default" ACL.
  */
 int Xorriso_normalize_acl_text(struct XorrisO *xorriso, char *in_text,
