@@ -323,7 +323,7 @@ int Xorriso_restore_properties(struct XorrisO *xorriso, char *disk_path,
  gid= iso_node_get_gid(node);
  if(!(S_ISDIR(stbuf.st_mode) && (flag&2)))
    uid= iso_node_get_uid(node);
- chown(disk_path, uid, gid); /* don't complain if it fails */
+ ret= chown(disk_path, uid, gid); /* don't complain if it fails */
  utime_buffer.actime= iso_node_get_atime(node);
  utime_buffer.modtime= iso_node_get_mtime(node);
  ret= utime(disk_path,&utime_buffer);
