@@ -359,7 +359,7 @@ int Xorriso_read_lines(struct XorrisO *xorriso, FILE *fp, int *linecount,
  linept= line;
  base_length= 0;
  while(1) {
-   fgot= Sfile_fgets_n(linept, SfileadrL - base_length + 1, fp,
+   fgot= Sfile_fgets_n(linept, SfileadrL - base_length - 1, fp,
                        !!(flag & (1 | 8)));
    if(fgot == NULL) {
      if(ferror(fp))
@@ -938,12 +938,27 @@ int Xorriso_msgs_submit(struct XorrisO *xorriso,
  else
    xorriso->info_text[li+lt]= '\n';
  xorriso->info_text[li+lt+1]= 0;
+
+#ifdef NIX
+
+ /* <<< */
  Xorriso_info(xorriso,4|(flag&3));
  if(os_errno>0) {
-   sprintf(xorriso->info_text, "%ssys   : %s\n",
-           pfx_list[(flag>>2)&15], strerror(os_errno));
+   sprintf(xorriso->info_text, "%s%s : %s\n",
+           pfx_list[(flag>>2)&15], sev_text, strerror(os_errno));
    Xorriso_info(xorriso,4|(flag&3));
  }
+
+#else
+
+ if(os_errno>0) {
+   sprintf(xorriso->info_text + strlen(xorriso->info_text) - 1,
+           " : %s\n", strerror(os_errno));
+ }
+ Xorriso_info(xorriso,4|(flag&3));
+
+#endif
+
  return(1);   
 }
 
@@ -1423,6 +1438,23 @@ int Xorriso_status(struct XorrisO *xorriso, char *filter, FILE *fp, int flag)
  if(!(is_default && no_defaults))
    Xorriso_status_result(xorriso,filter,fp,flag&2);
 
+ is_default= (xorriso->copyright_file[0] == 0);
+ sprintf(line,"-copyright_file %s\n",
+        Text_shellsafe(xorriso->copyright_file,sfe,0));
+ if(!(is_default && no_defaults))
+   Xorriso_status_result(xorriso,filter,fp,flag&2);
+
+ is_default= (xorriso->biblio_file[0]==0);
+ sprintf(line,"-biblio_file %s\n",Text_shellsafe(xorriso->biblio_file,sfe,0));
+ if(!(is_default && no_defaults))
+   Xorriso_status_result(xorriso,filter,fp,flag&2);
+
+ is_default= (xorriso->abstract_file[0]==0);
+ sprintf(line,"-abstract_file %s\n",
+         Text_shellsafe(xorriso->abstract_file,sfe,0));
+ if(!(is_default && no_defaults))
+   Xorriso_status_result(xorriso,filter,fp,flag&2);
+
  is_default= (xorriso->do_joliet==0);
  sprintf(line,"-joliet %s\n", (xorriso->do_joliet == 1 ? "on" : "off"));
  if(!(is_default && no_defaults))
@@ -1886,6 +1918,8 @@ int Xorriso_pacifier_callback(struct XorrisO *xorriso, char *what_done,
    strcat(byte_text, ")");
  }
  if(count<=0.0 && !(flag&2)) {
+   if(since < 2)
+     return(2);
    sprintf(xorriso->info_text,
            "Thank you for being patient for %.f seconds", since);
  } else if(todo<=0.0) {
