@@ -487,7 +487,7 @@ ex:;
 int Xorriso_write_session(struct XorrisO *xorriso, int flag)
 {
  int ret, relax= 0, i, pacifier_speed= 0, data_lba, ext, is_bootable= 0;
- int major, minor, micro;
+ int major, minor, micro, freshly_bootable= 0, hide_attr;
  char xorriso_id[256], *img_id, sfe[5*SfileadrL], *out_cs;
  struct isoburn_imgen_opts *sopts= NULL;
  struct burn_drive_info *dinfo, *source_dinfo;
@@ -566,6 +566,9 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
    iso_image_set_publisher_id(image, xorriso->publisher);
    iso_image_set_system_id(image, xorriso->system_id);
    iso_image_set_volset_id(image, xorriso->volset_id);
+   iso_image_set_copyright_file_id(image, xorriso->copyright_file);
+   iso_image_set_biblio_file_id(image, xorriso->biblio_file);
+   iso_image_set_abstract_file_id(image, xorriso->abstract_file);
  }
 
  if((xorriso->do_aaip & 256) && out_cs != NULL) {
@@ -590,6 +593,7 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
      ret= Xorriso_attach_boot_image(xorriso, xorriso->boot_count == 0);
      if(ret <= 0)
        goto ex;
+     freshly_bootable= 1;
    }
    if(xorriso->boot_count > 0) {
      /* Eventually rename boot catalog node to changed boot_image_cat_path */
@@ -604,6 +608,12 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
          }
        }
      }
+     hide_attr= !!(xorriso->boot_image_cat_hidden);
+     if(xorriso->boot_image_cat_hidden & 1)
+       hide_attr|= LIBISO_HIDE_ON_RR;
+     if(xorriso->boot_image_cat_hidden & 2)
+       hide_attr|= LIBISO_HIDE_ON_JOLIET;
+     iso_image_set_boot_catalog_hidden(image, hide_attr);
    } else if(xorriso->patch_isolinux_image & 1) {
      if(is_bootable == 1) {
        relax|= isoburn_igopt_allow_full_ascii;
@@ -629,7 +639,7 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
        ret= Xorriso_set_isolinux_options(xorriso, image, 0);
        if(ret <= 0)
          goto ex;
-     } else {
+     } else if(!freshly_bootable) {
        sprintf(xorriso->info_text,
                "Could not find any boot image for -boot_image patching");
        Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "WARNING", 0);
@@ -1988,7 +1998,10 @@ int Xorriso_update_iso_lba0(struct XorrisO *xorriso, int iso_lba, int isosize,
  char *headpt;
  struct burn_drive_info *dinfo;
  struct burn_drive *drive;
- off_t seek_ret;
+ off_t seek_ret, to_write;
+ int tag_type;
+ uint32_t pos, range_start, range_size, next_tag;
+ char md5[16];
 
  ret= Xorriso_may_burn(xorriso, 0);
  if(ret <= 0)
@@ -2040,6 +2053,14 @@ int Xorriso_update_iso_lba0(struct XorrisO *xorriso, int iso_lba, int isosize,
        Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, errno, "FAILURE",0);
        return(0);
      }
+     ret= isoburn_read_iso_head(drive, 0, &isosize, head_buffer, 1 << 13);
+     if(ret<=0) {
+       Xorriso_process_msg_queues(xorriso,0);
+       sprintf(xorriso->info_text,
+               "Alleged session start does not like ISO 9660.");
+       Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, errno, "FAILURE",0);
+       return(0);
+     }
    } else {
      ret= isoburn_read_iso_head(drive, iso_lba, &isosize, head_buffer, 2);
      if(ret<=0) {
@@ -2057,13 +2078,33 @@ int Xorriso_update_iso_lba0(struct XorrisO *xorriso, int iso_lba, int isosize,
  for(i=0;i<4;i++)
    headpt[87-i]= headpt[80+i]= (full_size >> (8*i)) & 0xff;
 
+
  if(job != NULL) {
+   /* This is a check_media superblock relocation:
+      Invalidate eventual libisofs checksum tags.
+      Write only up to PVD end plus eventual invalidated tag.
+   */
+   /* Look for volume descriptor end */
+   for(i= 16; i < 32; i++)
+     if(((unsigned char *) head_buffer)[i * 2048] == 0xff &&
+        strncmp(head_buffer + i * 2048 + 1, "CD001", 5) == 0)
+   break;
+   /* Check whether the next one is a libisofs checksum tag */
+   if(i < 32) {
+     i++;
+     ret= iso_util_decode_md5_tag(head_buffer + i * 2048, &tag_type, &pos,
+                                &range_start, &range_size, &next_tag, md5, 0);
+     if(ret != 0) /* corrupted or not: invalidate */
+       memset(head_buffer + i * 2048, 0, 8);
+   }
+   to_write= 2048 * (i + 1);
+
    seek_ret= lseek(job->data_to_fd, (off_t) 0, SEEK_SET);
    if(seek_ret == -1)
      ret= 0;
    else
-     ret= write(job->data_to_fd, head_buffer, 64 * 1024); 
-   if(ret < 64 * 1024) {
+     ret= write(job->data_to_fd, head_buffer, to_write); 
+   if(ret < to_write) {
      Xorriso_process_msg_queues(xorriso,0);
      sprintf(xorriso->info_text,
              "Cannot write ISO image head to file copy"); 
@@ -2071,8 +2112,9 @@ int Xorriso_update_iso_lba0(struct XorrisO *xorriso, int iso_lba, int isosize,
      return(0);
    }
  } else {
-   ret= burn_random_access_write(drive, (off_t) 0, head_buffer,
-                                 (off_t) (64*1024), 1);
+   /* This is a regular superblock relocation. Write full 64 kB. */
+   to_write= 64 * 1024;
+   ret= burn_random_access_write(drive, (off_t) 0, head_buffer, to_write, 1);
    if(ret<=0) {
      Xorriso_process_msg_queues(xorriso,0);
      sprintf(xorriso->info_text,
