@@ -22,6 +22,12 @@
    Mandatory calls are:
      Xorriso_new(), Xorriso_startup_libraries(), Xorriso_destroy()
 
+   This architecture is fully public since version 0.5.8. From then on, new
+   features get marked by
+     @since major.minor.micro
+   If this mark is missing, then the feature was present before release 0.5.8.
+
+
    There is a lower level of API which consists of libisofs.h, libburn.h and
    libisoburn.h. One should not mix those calls with the ones of xorriso.h .
 */
@@ -49,8 +55,8 @@ struct XorrisO;
     @since 0.5.8
 */
 #define Xorriso_header_version_majoR  0
-#define Xorriso_header_version_minoR  5
-#define Xorriso_header_version_micrO  8
+#define Xorriso_header_version_minoR  6
+#define Xorriso_header_version_micrO  0
 
 
 /** Eventually something like ".pl01" to indicate a bug fix. Normally empty.
@@ -564,11 +570,13 @@ int Xorriso_lst_destroy_all(struct Xorriso_lsT **lstring, int flag);
 /* Option -abort_on */
 int Xorriso_option_abort_on(struct XorrisO *xorriso, char *severity, int flag);
 
+/* Option -abstract_file */
+int Xorriso_option_abstract_file(struct XorrisO *xorriso, char *name,
+                                 int flag);
 
 /* Option -acl "on"|"off" */
 int Xorriso_option_acl(struct XorrisO *xorriso, char *mode, int flag);
 
-
 /* Option -add */
 /* @param flag bit0=do not report the added item
                bit1=do not reset pacifier, no final pacifier message
@@ -613,6 +621,9 @@ int Xorriso_option_backslash_codes(struct XorrisO *xorriso, char *mode,
 /* Option -ban_stdio_write */
 int Xorriso_option_ban_stdio_write(struct XorrisO *xorriso, int flag);
 
+/* Option -biblio_file */
+int Xorriso_option_biblio_file(struct XorrisO *xorriso, char *name, int flag);
+
 /* Option -blank and -format */
 /* @param flag bit0= format rather than blank
    @return <=0 error , 1 success, 2 revoked by -reassure
@@ -704,6 +715,10 @@ int Xorriso_option_compare(struct XorrisO *xorriso, char *disk_path,
 /* Option -compliance */
 int Xorriso_option_compliance(struct XorrisO *xorriso, char *mode, int flag);
 
+/* Option -copyright_file */
+int Xorriso_option_copyright_file(struct XorrisO *xorriso, char *name,
+                                  int flag);
+
 /* Option -cpr alias -cpri */
 int Xorriso_option_cpri( struct XorrisO *xorriso, int argc, char **argv,
                          int *idx, int flag);
@@ -821,6 +836,10 @@ int Xorriso_option_hardlinks(struct XorrisO *xorriso, char *mode, int flag);
 /* Option -help and part of -prog_help */
 int Xorriso_option_help(struct XorrisO *xorriso, int flag);
 
+/* Option -hide */
+int Xorriso_option_hide(struct XorrisO *xorriso, char *hide_state,
+                        int argc, char **argv, int *idx, int flag);
+
 /* Option -history */
 int Xorriso_option_history(struct XorrisO *xorriso, char *line, int flag);
 
@@ -917,7 +936,12 @@ int Xorriso_option_mvi(struct XorrisO *xorriso, int argc, char **argv,
 /* Option -no_rc */
 int Xorriso_option_no_rc(struct XorrisO *xorriso, int flag);
 
-/* Option -not_leaf */
+/* Option -not_leaf , -as mkisofs -hide without '/' */
+/* @param flag  bit0= add to iso_rr hide list rather than to disk exclusions
+                      @since 0.6.0
+                bit1= add to joliet hide list rather than disk exclusions
+                      @since 0.6.0
+*/
 int Xorriso_option_not_leaf(struct XorrisO *xorriso, char *pattern, int flag);
 
 /* Option -not_list , -quoted_not_list */
@@ -927,7 +951,13 @@ int Xorriso_option_not_list(struct XorrisO *xorriso, char *adr, int flag);
 /* Option -not_mgt */
 int Xorriso_option_not_mgt(struct XorrisO *xorriso, char *setting, int flag);
 
-/* Option -not_paths */
+/* Option -not_paths , -as mkisofs -hide with '/' */
+/* @param flag  bit0= add to iso_rr hide list rather than to disk exclusions
+                      @since 0.6.0
+                bit1= add to joliet hide list rather than disk exclusions
+                      @since 0.6.0
+                bit2= enable disk pattern expansion regardless of -disk_pattern
+*/ 
 int Xorriso_option_not_paths(struct XorrisO *xorriso, int argc, char **argv,
                              int *idx, int flag);
 
@@ -994,6 +1024,9 @@ int Xorriso_option_pwdi(struct XorrisO *xorriso, int flag);
 /* Option -pwdx */
 int Xorriso_option_pwdx(struct XorrisO *xorriso, int flag);
 
+/* Option -read_mkisofsrc */
+int Xorriso_option_read_mkisofsrc(struct XorrisO *xorriso, int flag);
+
 /* Option -reassure "on"|"tree"|"off" */
 int Xorriso_option_reassure(struct XorrisO *xorriso, char *mode, int flag);
 
@@ -1118,6 +1151,8 @@ int Xorriso_option_use_readline(struct XorrisO *xorriso, char *mode, int flag);
 int Xorriso_option_version(struct XorrisO *xorriso, int flag);
 
 /* Option -volid */
+/* @param flag bit0= do not warn of problematic volid
+*/
 int Xorriso_option_volid(struct XorrisO *xorriso, char *volid, int flag);
 
 /* Option -volset_id */
