@@ -30,7 +30,7 @@
 
    xorriso is the higher level API of libisoburn which allows to operate all
    three libraries by a unified set of commands. 
-   xorriso.h exposes the public functions.
+   <libisoburn/xorriso.h> exposes the public functions.
    Among these functions are direct equivalents of the xorriso interpreter
    commands. There are also functions for fundamental management and for
    handling event messages.
@@ -40,10 +40,15 @@
    One should not mix the use of the xorriso API with the use of the lower
    level APIs of libburn, libisofs, libisoburn.
    
+   --------------------------------------------------------------------------
+   The following overview is relevant for development but not for usage of
+   xorriso. An application programmer should read xorriso.h and man xorriso
+   resp. info xorriso, rather than diving into its source code.
+   --------------------------------------------------------------------------
 
    The xorriso source is divided in two groups:
 
-   A set of source modules interacts with the libraries:
+   A set of source modules interacts with the lower level library APIs:
 
    base_obj.[ch]    fundamental operations of the XorrisO object
    lib_mgt.[ch]     manages the relation between xorriso and the libraries
@@ -57,7 +62,7 @@
    filters.[ch]     operates on data filter objects
    xorrisoburn.h    declarations needed by the non-library modules
 
-   Another set is independent of the liburnia libraries:
+   Another set is independent of the lower level APIs:
 
    parse_exec.c     deals with parsing and interpretation of command input
    sfile.c          functions around files and strings
@@ -100,11 +105,12 @@
 #include "xorriso.h"
 
 
-/* The minimum version of libisoburn to be used with this version of xorriso
+/* The minimum version of libisoburn xorriso API to be used with this
+   version of xorriso.
 */
 #define Xorriso_req_majoR  0
-#define Xorriso_req_minoR  5
-#define Xorriso_req_micrO  7
+#define Xorriso_req_minoR  6
+#define Xorriso_req_micrO  0
 
 
 static void yell_xorriso()
