@@ -18,8 +18,8 @@
 /* The minimum version of libisoburn to be used with this version of xorriso
 */
 #define xorriso_libisoburn_req_major  0
-#define xorriso_libisoburn_req_minor  5
-#define xorriso_libisoburn_req_micro  8
+#define xorriso_libisoburn_req_minor  6
+#define xorriso_libisoburn_req_micro  0
 
 
 struct SpotlisT;          /* List of intervals with different read qualities */
@@ -531,5 +531,8 @@ int Xorriso_reaquire_outdev(struct XorrisO *xorriso, int flag);
 int Xorriso_set_system_area_path(struct XorrisO *xorriso, char *path,
                                  int flag);
 
+int Xorriso_set_hidden(struct XorrisO *xorriso, void *in_node, char *path,
+                       int hide_state, int flag);
+
 #endif /* Xorrisoburn_includeD */
 
